@@ -178,6 +178,11 @@ public class QueryException extends ValidationException {
     public final static int LIST_ORDER_FIELD_WRONG_VALUE = 6162;
     public final static int INDEX_REQUIRES_QUERY_KEY_EXPRESSION = 6163;
     public final static int INDEX_REQUIRES_COLLECTION_MAPPING_WITH_LIST_ORDER_FIELD = 6164;
+    public final static int BATCH_IN_REQUIRES_SINGLETON_PK = 6165;
+    public final static int COULD_NOT_FIND_CAST_DESCRIPTOR = 6166;
+    public final static int CAST_MUST_USE_INHERITANCE = 6167;
+    public final static int PREPARE_FAILED = 6168;
+    public final static int ORIGINAL_QUERY_MUST_USE_IN = 6169;
 
     /**
      * INTERNAL:
@@ -239,7 +244,7 @@ public class QueryException extends ValidationException {
     }
     
     public static QueryException backupCloneIsDeleted(Object clone) {
-        Object[] args = { clone, clone.getClass(), new Integer(System.identityHashCode(clone)), CR };
+        Object[] args = { clone, clone.getClass(), Integer.valueOf(System.identityHashCode(clone)), CR };
 
         QueryException queryException = new QueryException(ExceptionMessageGenerator.buildMessage(QueryException.class, BACKUP_CLONE_DELETED, args));
         queryException.setErrorCode(BACKUP_CLONE_DELETED);
@@ -248,7 +253,7 @@ public class QueryException extends ValidationException {
 
     public static QueryException backupCloneIsOriginalFromParent(Object clone) {
         // need to be verified
-        Object[] args = { clone, clone.getClass(), new Integer(System.identityHashCode(clone)), CR };
+        Object[] args = { clone, clone.getClass(), Integer.valueOf(System.identityHashCode(clone)), CR };
 
         QueryException queryException = new QueryException(ExceptionMessageGenerator.buildMessage(QueryException.class, BACKUP_CLONE_IS_ORIGINAL_FROM_PARENT, args));
         queryException.setErrorCode(BACKUP_CLONE_IS_ORIGINAL_FROM_PARENT);
@@ -256,7 +261,7 @@ public class QueryException extends ValidationException {
     }
 
     public static QueryException backupCloneIsOriginalFromSelf(Object clone) {
-        Object[] args = { clone, clone.getClass(), new Integer(System.identityHashCode(clone)), CR };
+        Object[] args = { clone, clone.getClass(), Integer.valueOf(System.identityHashCode(clone)), CR };
 
         QueryException queryException = new QueryException(ExceptionMessageGenerator.buildMessage(QueryException.class, BACKUP_CLONE_IS_ORIGINAL_FROM_SELF, args));
         queryException.setErrorCode(BACKUP_CLONE_IS_ORIGINAL_FROM_SELF);
@@ -881,7 +886,7 @@ public class QueryException extends ValidationException {
         return queryException;
     }
 
-    public static QueryException classPkDoesNotExistInCache(Class theClass, java.util.Vector primaryKey) {
+    public static QueryException classPkDoesNotExistInCache(Class theClass, Object primaryKey) {
         Object[] args = { theClass, primaryKey };
 
         QueryException queryException = new QueryException(ExceptionMessageGenerator.buildMessage(QueryException.class, CLASS_PK_DOES_NOT_EXIST_IN_CACHE, args));
@@ -1010,7 +1015,7 @@ public class QueryException extends ValidationException {
     }
 
     public static QueryException reportQueryResultSizeMismatch(int expected, int retrieved) {
-        Object[] args = { new Integer(expected), new Integer(retrieved) };
+        Object[] args = { Integer.valueOf(expected), Integer.valueOf(retrieved) };
 
         QueryException queryException = new QueryException(ExceptionMessageGenerator.buildMessage(QueryException.class, REPORT_QUERY_RESULT_SIZE_MISMATCH, args));
         queryException.setErrorCode(REPORT_QUERY_RESULT_SIZE_MISMATCH);
@@ -1493,4 +1498,45 @@ public class QueryException extends ValidationException {
         return queryException;
     }
 
+    public static QueryException batchReadingInRequiresSingletonPrimaryKey(DatabaseQuery query) {
+        Object[] args = {  };
+
+        QueryException queryException = new QueryException(ExceptionMessageGenerator.buildMessage(QueryException.class, BATCH_IN_REQUIRES_SINGLETON_PK, args), query);
+        queryException.setErrorCode(BATCH_IN_REQUIRES_SINGLETON_PK);
+        return queryException;
+    }
+    
+    public static QueryException couldNotFindCastDescriptor(Class castClass, Expression base) {
+        Object[] args = { castClass, base };
+
+        QueryException queryException = new QueryException(ExceptionMessageGenerator.buildMessage(QueryException.class, COULD_NOT_FIND_CAST_DESCRIPTOR, args));
+        queryException.setErrorCode(COULD_NOT_FIND_CAST_DESCRIPTOR);
+        return queryException;
+    }
+
+    public static QueryException castMustUseInheritance(Expression base) {
+        Object[] args = { base };
+
+        QueryException queryException = new QueryException(ExceptionMessageGenerator.buildMessage(QueryException.class, CAST_MUST_USE_INHERITANCE, args));
+        queryException.setErrorCode(CAST_MUST_USE_INHERITANCE);
+        return queryException;
+    }
+
+    public static QueryException prepareFailed(Exception error, DatabaseQuery query) {
+        Object[] args = { error };
+
+        QueryException queryException = new QueryException(ExceptionMessageGenerator.buildMessage(QueryException.class, PREPARE_FAILED, args), query, error);
+        queryException.setErrorCode(PREPARE_FAILED);
+        return queryException;
+    }
+
+    public static QueryException originalQueryMustUseBatchIN(DatabaseMapping mapping, DatabaseQuery query) {
+        Object[] args = { mapping };
+
+        QueryException queryException = new QueryException(ExceptionMessageGenerator.buildMessage(QueryException.class, ORIGINAL_QUERY_MUST_USE_IN, args), query);
+        queryException.setErrorCode(ORIGINAL_QUERY_MUST_USE_IN);
+        return queryException;
+    }
+    
 }
+
