@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 1998, 2010 Oracle. All rights reserved.
+ * Copyright (c) 1998, 2011 Oracle. All rights reserved.
  * This program and the accompanying materials are made available under the 
  * terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
  * which accompanies this distribution. 
@@ -340,7 +340,7 @@ public class IdentityMapManager implements Serializable, Cloneable {
                     constructor = (Constructor)AccessController.doPrivileged(new PrivilegedGetConstructorFor(identityMapClass, new Class[] { ClassConstants.PINT, ClassDescriptor.class }, false));
                     IdentityMap map = (IdentityMap)AccessController.doPrivileged(new PrivilegedInvokeConstructor(constructor, new Object[] { Integer.valueOf(size), descriptor }));
                     if ((descriptor != null) && (descriptor.getCacheInterceptorClass() != null)) {
-                        constructor = (Constructor)AccessController.doPrivileged(new PrivilegedGetConstructorFor(identityMapClass, new Class[] { IdentityMap.class, AbstractSession.class }, false));
+                        constructor = (Constructor)AccessController.doPrivileged(new PrivilegedGetConstructorFor(descriptor.getCacheInterceptorClass(), new Class[] { IdentityMap.class, AbstractSession.class }, false));
                         Object params[] = new Object[]{map, this.session};
                         map = (IdentityMap)AccessController.doPrivileged(new PrivilegedInvokeConstructor(constructor, params));
                     }
@@ -1161,7 +1161,7 @@ public class IdentityMapManager implements Serializable, Cloneable {
             }
         }
         writer.write(Helper.cr() + TraceLocalization.buildMessage("lock_writer_footer", (Object[])null) + Helper.cr());
-        this.session.log(SessionLog.FINEST, SessionLog.CACHE, writer.toString(), null, null, false);
+        this.session.log(SessionLog.SEVERE, SessionLog.CACHE, writer.toString(), null, null, false);
     }
 
     /**
@@ -1200,7 +1200,7 @@ public class IdentityMapManager implements Serializable, Cloneable {
             }
         }
         writer.write(Helper.cr() + TraceLocalization.buildMessage("lock_writer_footer", (Object[])null) + Helper.cr());
-        this.session.log(SessionLog.FINEST, SessionLog.CACHE, writer.toString(), null, null, false);
+        this.session.log(SessionLog.SEVERE, SessionLog.CACHE, writer.toString(), null, null, false);
     }
 
     /**
