@@ -37,6 +37,10 @@
  *       - 267217: Add Named Access Type to EclipseLink-ORM
  *     04/27/2010-2.1 Guy Pelletier 
  *       - 309856: MappedSuperclasses from XML are not being initialized properly
+ *     07/05/2010-2.1.1 Guy Pelletier 
+ *       - 317708: Exception thrown when using LAZY fetch on VIRTUAL mapping
+ *     08/04/2010-2.1.1 Guy Pelletier
+ *       - 315782: JPA2 derived identity metadata processing validation doesn't account for autoboxing
  ******************************************************************************/  
 package org.eclipse.persistence.internal.jpa.metadata.accessors.mappings;
 
@@ -67,6 +71,7 @@ import org.eclipse.persistence.internal.jpa.metadata.MetadataLogger;
 import org.eclipse.persistence.internal.helper.ClassConstants;
 import org.eclipse.persistence.internal.helper.DatabaseField;
 import org.eclipse.persistence.internal.helper.DatabaseTable;
+import org.eclipse.persistence.internal.helper.Helper;
 import org.eclipse.persistence.internal.indirection.WeavedObjectBasicIndirectionPolicy;
 
 import org.eclipse.persistence.mappings.DatabaseMapping;
@@ -250,6 +255,17 @@ public abstract class ObjectAccessor extends RelationshipAccessor {
         }
     }
     
+    /**
+     * INTERNAL:
+     * Object accessors don't require a separate attribute-type specification
+     * in XML, instead they can use the reference class to determine the
+     * attribute-type.
+     */
+    @Override
+    public boolean hasAttributeType() {
+        return getReferenceClass() != null;
+    }
+    
     /**
      * INTERNAL:
      */
@@ -419,21 +435,22 @@ public abstract class ObjectAccessor extends RelationshipAccessor {
     protected void processId(OneToOneMapping mapping) {
         // If this entity has a pk class, we need to validate our ids.
         MetadataDescriptor referenceDescriptor = getReferenceDescriptor();
-        String keyname = referenceDescriptor.getPKClassName();
+        String referencePKClassName = referenceDescriptor.getPKClassName();
 
-        if (keyname != null) {
+        if (referencePKClassName != null) {
             // They have a pk class
-            String ourpkname = getDescriptor().getPKClassName();
-            if (ourpkname == null){
-                throw ValidationException.invalidCompositePKSpecification(getJavaClass(), ourpkname);
+            String pkClassName = getDescriptor().getPKClassName();
+            if (pkClassName == null){
+                throw ValidationException.invalidCompositePKSpecification(getJavaClass(), pkClassName);
             }
             
-            if (! ourpkname.equals(keyname)){
-                // Validate our pk contains their pk.
-                getOwningDescriptor().validatePKClassId(getAttributeName(), referenceDescriptor.getPKClass());
-            } else {
-                // This pk is the reference pk, so all pk attributes are accounted through this relationship
+            if (pkClassName.equals(referencePKClassName)){
+                // This pk is the reference pk, so all pk attributes are 
+                // accounted through this relationship.
                 getOwningDescriptor().getPKClassIDs().clear();
+            } else {
+                // Validate our pk contains their pk.
+                getOwningDescriptor().validateDerivedPKClassId(getAttributeName(), referencePKClassName, getReferenceClassName());
             }
         } else {
             MetadataClass type = null;
@@ -447,7 +464,7 @@ public abstract class ObjectAccessor extends RelationshipAccessor {
                 type = referenceDescriptor.getAccessorFor(referenceDescriptor.getIdAttributeName()).getRawClass();
             }
             
-            getOwningDescriptor().validatePKClassId(getAttributeName(), type);
+            getOwningDescriptor().validateDerivedPKClassId(getAttributeName(), getBoxedType(type.getName()), getReferenceClassName());
         }
 
         // Store the Id attribute name. Used with validation and OrderBy.
@@ -472,9 +489,15 @@ public abstract class ObjectAccessor extends RelationshipAccessor {
                 && (!ClassConstants.PersistenceWeavedLazy_Class.isAssignableFrom(getJavaClass(getDescriptor().getJavaClass())))) {
             usesIndirection = false;
         }
+        String actualAttributeType = getAttributeType();
+        if (getAccessibleObject() != null){
+            actualAttributeType = getAccessibleObject().getType();
+        }
         
         if (usesIndirection && usesPropertyAccess()) {
-            mapping.setIndirectionPolicy(new WeavedObjectBasicIndirectionPolicy(getSetMethodName()));
+            mapping.setIndirectionPolicy(new WeavedObjectBasicIndirectionPolicy(getGetMethodName(), getSetMethodName(), actualAttributeType, true));
+        } else if (usesIndirection && usesFieldAccess()) {
+            mapping.setIndirectionPolicy(new WeavedObjectBasicIndirectionPolicy(Helper.getWeavedGetMethodName(mapping.getAttributeName()), Helper.getWeavedSetMethodName(mapping.getAttributeName()), actualAttributeType, false));
         } else {
             mapping.setUsesIndirection(usesIndirection);
         }
