@@ -256,8 +256,7 @@ public class StoredProcedureParameterMetadata extends ORMetadata {
         if (project.useDelimitedIdentifier()) {
             field.setUseDelimiters(true);
         } else if (project.getShouldForceFieldNamesToUpperCase() && !field.shouldUseDelimiters()) {
-            //done directly as this field's name should be in uppercase.
-            field.setName(field.getName().toUpperCase());
+            field.useUpperCaseForComparisons(true);
         }
     }
     
