@@ -19,6 +19,7 @@ import org.eclipse.persistence.internal.descriptors.Namespace;
 import org.eclipse.persistence.internal.helper.Helper;
 import org.eclipse.persistence.internal.oxm.record.ObjectMarshalContext;
 import org.eclipse.persistence.internal.oxm.record.MarshalContext;
+import org.eclipse.persistence.internal.oxm.record.XMLReader;
 import org.eclipse.persistence.internal.oxm.record.deferred.AnyMappingContentHandler;
 import org.eclipse.persistence.internal.queries.ContainerPolicy;
 import org.eclipse.persistence.internal.sessions.AbstractSession;
@@ -29,6 +30,7 @@ import org.eclipse.persistence.oxm.NamespaceResolver;
 import org.eclipse.persistence.oxm.XMLConstants;
 import org.eclipse.persistence.oxm.XMLContext;
 import org.eclipse.persistence.oxm.XMLDescriptor;
+import org.eclipse.persistence.oxm.XMLField;
 import org.eclipse.persistence.oxm.XMLMarshaller;
 import org.eclipse.persistence.oxm.XMLRoot;
 import org.eclipse.persistence.oxm.mappings.UnmarshalKeepAsElementPolicy;
@@ -99,9 +101,9 @@ public class XMLAnyCollectionMappingNodeValue extends XMLRelationshipMappingNode
                 // Check if descriptor is for a wrapper, if it is null it out and let continue
                 if (workingDescriptor != null && workingDescriptor.isWrapper()) {
                     workingDescriptor = null;
-                }                       
-            }  
-         
+                }
+            }
+
             UnmarshalKeepAsElementPolicy policy = xmlAnyCollectionMapping.getKeepAsElementPolicy();
             if (((workingDescriptor == null) && (policy == UnmarshalKeepAsElementPolicy.KEEP_UNKNOWN_AS_ELEMENT)) || (policy == UnmarshalKeepAsElementPolicy.KEEP_ALL_AS_ELEMENT)) {
                 setupHandlerForKeepAsElementPolicy(unmarshalRecord, xPathFragment, atts);
@@ -115,7 +117,9 @@ public class XMLAnyCollectionMappingNodeValue extends XMLRelationshipMappingNode
                     qnameString = xPathFragment.getPrefix() + XMLConstants.COLON + qnameString;
                 }
                 handler.startElement(xPathFragment.getNamespaceURI(), xPathFragment.getLocalName(), qnameString, atts);
-                unmarshalRecord.getXMLReader().setContentHandler(handler);
+                XMLReader xmlReader = unmarshalRecord.getXMLReader();
+                xmlReader.setContentHandler(handler);
+                xmlReader.setLexicalHandler(handler);
                 return true;
             }
         } catch (SAXException e) {
@@ -179,7 +183,7 @@ public class XMLAnyCollectionMappingNodeValue extends XMLRelationshipMappingNode
     }
     
     protected void setOrAddAttributeValue(UnmarshalRecord unmarshalRecord, Object value, XPathFragment xPathFragment, Object collection){
-        if (!xmlAnyCollectionMapping.usesXMLRoot()) {
+        if (!xmlAnyCollectionMapping.usesXMLRoot() || xPathFragment.getLocalName() == null) {
             unmarshalRecord.addAttributeValue(this, value);
         } else {
             XMLRoot xmlRoot = new XMLRoot();
@@ -305,13 +309,9 @@ public class XMLAnyCollectionMappingNodeValue extends XMLRelationshipMappingNode
                 getXPathNode().startElement(marshalRecord, rootFragment, object, childSession, marshalRecord.getNamespaceResolver(), objectBuilder, value);                
 
                 writeExtraNamespaces(extraNamespaces, marshalRecord, session);
-                if (xmlAnyCollectionMapping.shouldAddXsiType(marshaller, descriptor, originalValue, wasXMLRoot)) {
-                    String typeValue = descriptor.getSchemaReference().getSchemaContext();
-                    addTypeAttribute(descriptor, marshalRecord, typeValue);
-                }
-
-                objectBuilder.buildRow(marshalRecord, value, session, marshaller, WriteType.UNDEFINED);
 
+                objectBuilder.addXsiTypeAndClassIndicatorIfRequired(marshalRecord, descriptor, descriptor, (XMLField)xmlAnyCollectionMapping.getField(), originalValue, value, wasXMLRoot, false);               
+                objectBuilder.buildRow(marshalRecord, value, session, marshaller, WriteType.UNDEFINED);                
                 objectBuilder.removeExtraNamespacesFromNamespaceResolver(marshalRecord, extraNamespaces, session);
 
                 marshalRecord.endElement(rootFragment, namespaceResolver);
