@@ -415,12 +415,9 @@ public class XMLCompositeObjectMappingNodeValue extends XMLRelationshipMappingNo
 	                    // if we have a user-set type, try to get the class from the inheritance policy
 	                    if (leafElementType != null) {
 	                        Object indicator = xmlDescriptor.getInheritancePolicy().getClassIndicatorMapping().get(leafElementType);
-
-	                        // if the inheritance policy does not contain the user-set type, throw an exception
-	                        if (indicator == null) {
-	                            throw DescriptorException.missingClassForIndicatorFieldValue(leafElementType, xmlDescriptor.getInheritancePolicy().getDescriptor());
+	                        if(indicator != null) {
+	                            clazz = (Class)indicator;
 	                        }
-	                        clazz = (Class)indicator;
 	                    }
 	                }
 
