@@ -38,8 +38,9 @@ public class ObjectRelationalDatabaseField extends DatabaseField {
         this.setName(field.getName());
         this.setTable(field.getTable());
         this.setType(field.getType());
-        this.setOriginalName(field.getOriginalName());
         this.setUseDelimiters(field.shouldUseDelimiters());
+        this.useUpperCaseForComparisons(field.getUseUpperCaseForComparisons());
+        this.setNameForComparisons(field.getNameForComparisons());
         if (field.getType() != null) {
             this.setTypeName(field.getType().getName());
         }
