@@ -513,11 +513,9 @@ public class XMLCompositeCollectionMapping extends AbstractCompositeCollectionMa
                     QName leafElementType = ((XMLField) getField()).getLeafElementType();
                     if (leafElementType != null) {
                         Object indicator = aDescriptor.getInheritancePolicy().getClassIndicatorMapping().get(leafElementType);
-                        // if the inheritance policy does not contain the user-set type, throw an exception
-                        if (indicator == null) {
-                            throw DescriptorException.missingClassForIndicatorFieldValue(leafElementType, aDescriptor.getInheritancePolicy().getDescriptor());
+                        if(indicator != null) {
+                            newElementClass = (Class) indicator;
                         }
-                        newElementClass = (Class) indicator;
                     }
                 }
                 if (newElementClass != null) {
